@@ -30,10 +30,14 @@ __all__: typing.Final[typing.List[str]] = [
     "has_roles",
     "has_guild_permissions",
     "bot_has_guild_permissions",
+    "has_permissions",
+    "bot_has_permissions",
     "check",
 ]
 
 import functools
+import inspect
+import operator
 import types
 import typing
 
@@ -69,7 +73,7 @@ See https://tandemdude.gitlab.io/lightbulb/api-reference.html#module-lightbulb.c
 
 
 def _check_check_decorator_above_commands_decorator(func_or_command) -> None:
-    if isinstance(func_or_command, types.FunctionType):
+    if inspect.isfunction(func_or_command) or inspect.ismethod(func_or_command):
         raise SyntaxError(_CHECK_DECORATOR_BELOW_COMMAND_DECORATOR_MESSAGE)
 
 
@@ -106,6 +110,12 @@ async def _human_only(ctx: context.Context) -> bool:
     return True
 
 
+async def _nsfw_channel_only(ctx: context.Context) -> bool:
+    if not ctx.channel.is_nsfw:
+        raise errors.NSFWChannelOnly(f"{ctx.invoked_with} can only be used in an NSFW channel")
+    return True
+
+
 def _role_check(member_roles: typing.Sequence[hikari.Snowflake], *, roles: typing.Sequence[int], func) -> bool:
     return func(r in member_roles for r in roles)
 
@@ -158,6 +168,47 @@ async def _bot_has_guild_permissions(ctx: context.Context, *, permissions: hikar
     return True
 
 
+async def _has_permissions(ctx: context.Context, *, permissions: hikari.Permissions) -> bool:
+
+    await _guild_only(ctx)
+
+    perm_over = ctx.channel.permission_overwrites.values()
+    perm_none = hikari.Permissions.NONE
+
+    allowed_perms = functools.reduce(
+        operator.or_, (override.allow if override.id in ctx.member.role_ids else perm_none for override in perm_over)
+    )
+
+    missing_perms = allowed_perms ^ permissions
+
+    if missing_perms:
+        raise errors.MissingRequiredPermission(
+            "You are missing one or more permissions required in order to run this command", permissions=missing_perms
+        )
+    return True
+
+
+async def _bot_has_permissions(ctx: context.Context, *, permissions: hikari.Permissions) -> bool:
+
+    await _guild_only(ctx)
+
+    perm_over = ctx.channel.permission_overwrites.values()
+    perm_none = hikari.Permissions.NONE
+    bot_member = ctx.bot.cache.get_member(ctx.guild_id, ctx.bot.cache.get_me().id)
+
+    allowed_perms = functools.reduce(
+        operator.or_, (override.allow if override.id in bot_member.role_ids else perm_none for override in perm_over)
+    )
+
+    missing_perms = allowed_perms ^ permissions
+
+    if missing_perms:
+        raise errors.MissingRequiredPermission(
+            "You are missing one or more permissions required in order to run this command", permissions=missing_perms
+        )
+    return True
+
+
 def guild_only() -> typing.Callable[[T_inv], T_inv]:
     """
     A decorator that prevents a command from being used in direct messages.
@@ -232,6 +283,15 @@ def human_only() -> typing.Callable[[T_inv], T_inv]:
     return decorate
 
 
+def nsfw_channel_only() -> typing.Callable[[T_inv], T_inv]:
+    def decorate(command: T_inv) -> T_inv:
+        _check_check_decorator_above_commands_decorator(command)
+        command.add_check(_nsfw_channel_only)
+        return command
+
+    return decorate
+
+
 def has_roles(
     role1: snowflakes.SnowflakeishOr[hikari.PartialRole],
     *role_ids: snowflakes.SnowflakeishOr[hikari.PartialRole],
@@ -338,6 +398,60 @@ def bot_has_guild_permissions(perm1: hikari.Permissions, *permissions: hikari.Pe
     return decorate
 
 
+def has_permissions(perm1: hikari.Permissions, *permissions: hikari.Permissions):
+    """
+    A decorator that prevents the command from being used by a member missing any of the required
+    channel permissions (permissions granted by a permission overwrite).
+
+    Args:
+        perm1 (:obj:`hikari.Permissions`): Permission to check for.
+        *permissions (:obj:`hikari.Permissions`): Additional permissions to check for.
+
+    Note:
+        This check will also prevent commands from being used in DMs, as you cannot have permissions
+        in a DM channel.
+    """
+
+    def decorate(command: T_inv) -> T_inv:
+        _check_check_decorator_above_commands_decorator(command)
+        perms = perm1.split()
+
+        total_perms = functools.reduce(operator.or_, (*perms, *permissions))
+        command.user_required_permissions = total_perms
+
+        command.add_check(functools.partial(_has_permissions, permissions=total_perms))
+        return command
+
+    return decorate
+
+
+def bot_has_permissions(perm1: hikari.Permissions, *permissions: hikari.Permissions):
+    """
+    A decorator that prevents the command from being used if the bot is missing any of the required
+    channel permissions (permissions granted by a permission overwrite).
+
+    Args:
+        perm1 (:obj:`hikari.Permissions`): Permission to check for.
+        *permissions (:obj:`hikari.Permissions`): Additional permissions to check for.
+
+    Note:
+        This check will also prevent commands from being used in DMs, as you cannot have permissions
+        in a DM channel.
+    """
+
+    def decorate(command: T_inv) -> T_inv:
+        _check_check_decorator_above_commands_decorator(command)
+        perms = perm1.split()
+
+        total_perms = functools.reduce(operator.or_, (*perms, *permissions))
+        command.user_required_permissions = total_perms
+
+        command.add_check(functools.partial(_bot_has_permissions, permissions=total_perms))
+        return command
+
+    return decorate
+
+
 def check(check_func: typing.Callable[[context.Context], typing.Coroutine[typing.Any, typing.Any, bool]]):
     """
     A decorator which adds a custom check function to a command. The check function must be a coroutine (async def)
