@@ -30,7 +30,7 @@ import sys
 import typing
 
 import hikari
-from hikari.utilities import ux
+from hikari.internal import ux
 from multidict import CIMultiDict
 
 from lightbulb import commands
@@ -44,6 +44,7 @@ from lightbulb.utils import maybe_await
 
 _LOGGER = logging.getLogger("lightbulb")
 
+# XXX: can't we use `str.split()` here, which splits on all whitespace in the same way?
 ARG_SEP_REGEX = re.compile(r"(?:\s+|\n)")
 
 
@@ -97,13 +98,13 @@ def when_mentioned_or(prefix_provider):
     return get_prefixes
 
 
-def _return_prefix(
-    _, __, *, prefixes: typing.Union[str, typing.Iterable[str]]
-) -> typing.Union[str, typing.List[str], typing.Tuple[str]]:
+# Prefixes may be a string or iterable of strings. A string is a sequence of strings too by definition,
+# so this type hint _is_ correct.
+def _return_prefix(_: typing.Any, __: typing.Any, *, prefixes: typing.Iterable[str]) -> typing.Sequence[str]:
     return prefixes
 
 
-class Bot(hikari.Bot):
+class Bot(hikari.BotApp):
     """
     A subclassed implementation of :class:`hikari.impl.bot.BotAppImpl` which contains a command handler.
     This should be instantiated instead of the superclass if you want to be able to use
@@ -299,7 +300,7 @@ class Bot(hikari.Bot):
 
                 import lightbulb
 
-                bot = lightbulb.Bot(token="token_here", prefix="!")
+                bot = lightbulb.Bot(...)
 
                 async def ping(ctx):
                     await ctx.reply("Pong!")
@@ -520,9 +521,9 @@ class Bot(hikari.Bot):
 
             .. code-block:: python
 
-                from lightbulb import plugins
+                import lightbulb
 
-                class MyPlugin(plugins.Plugin):
+                class MyPlugin(lightbulb.Plugin):
                     ...
 
                 def load(bot):
@@ -560,9 +561,9 @@ class Bot(hikari.Bot):
 
             .. code-block:: python
 
-                from lightbulb import plugins
+                import lightbulb
 
-                class MyPlugin(plugins.Plugin):
+                class MyPlugin(lightbulb.Plugin):
                     ...
 
                 def load(bot):
@@ -636,13 +637,13 @@ class Bot(hikari.Bot):
             ``None``
         """
         if obj is None:
-            await self.help_class.send_help_overview(context)
+            await self.help_command.send_help_overview(context)
         elif isinstance(obj, commands.Group):
-            await self.help_class.send_group_help(context, obj)
+            await self.help_command.send_group_help(context, obj)
         elif isinstance(obj, commands.Command):
-            await self.help_class.send_command_help(context, obj)
+            await self.help_command.send_command_help(context, obj)
         elif isinstance(obj, plugins.Plugin):
-            await self.help_class.send_plugin_help(context, obj)
+            await self.help_command.send_plugin_help(context, obj)
 
     def get_context(
         self, message: hikari.Message, prefix: str, invoked_with: str, invoked_command: commands.Command
