@@ -54,7 +54,8 @@ __all__: typing.Final[typing.List[str]] = [
     "guild_voice_channel_converter",
     "category_converter",
     "role_converter",
-    "custom_emoji_converter",
+    "emoji_converter",
+    "guild_converter",
     "message_converter",
     "invite_converter",
     "colour_converter",
@@ -140,7 +141,7 @@ async def user_converter(arg: WrappedArg) -> hikari.User:
         .. code-block:: python
 
             @bot.command()
-            async def username(ctx, user: lightbulb.converters.user_converter):
+            async def username(ctx, user: lightbulb.user_converter):
                 await ctx.reply(user.username)
     """
     try:
@@ -301,29 +302,49 @@ async def role_converter(arg: WrappedArg) -> hikari.Role:
     return _raise_if_not_none(role)
 
 
-async def custom_emoji_converter(arg: WrappedArg) -> hikari.KnownCustomEmoji:
+async def emoji_converter(arg: WrappedArg) -> hikari.Emoji:
     """
-    Converter to transform a command argument into a :obj:`~hikari.KnownCustomEmoji` object.
+    Converter to transform a command argument into a :obj:`~hikari.Emoji` object.
+
+    Note that this **does not** validate unicode emojis to ensure they are defined
+    as standard emojis. See https://github.com/nekokatt/hikari/issues/270 for discussion
+    on supporting this.
 
     Args:
         arg (:obj:`WrappedArg`): Argument to transform.
 
     Returns:
-        :obj:`~hikari.emojis.KnownCustomEmoji`: The custom emoji object resolved from the argument.
+        :obj:`~hikari.Emoji`: The emoji object resolved from the argument.
 
     Raises:
-        :obj:`~.errors.ConverterFailure`: If the argument could not be resolved into a custom emoji object.
+        :obj:`~.errors.ConverterFailure`: If the argument could not be resolved into an emoji object.
     """
-    try:
-        emoji_id = _resolve_id_from_arg(arg.data, EMOJI_MENTION_REGEX)
-    except ValueError:
-        emojis = arg.context.bot.cache.get_emojis_view_for_guild(arg.context.guild_id)
-        emoji = utils.get(emojis.values(), name=arg.data)
+    return hikari.Emoji.parse(arg.data)
+
+
+async def guild_converter(arg: WrappedArg) -> hikari.GuildPreview:
+    """
+    Converter to transform a command argument into a :obj:`~hikari.Guild` object.
+
+    Args:
+        arg (:obj:`WrappedArg`): Argument to transform.
+
+    Returns:
+        :obj:`~hikari.Guild`: The guild object resolved from the argument.
+
+    Raises:
+        :obj:`~.errors.ConverterFailure`: If the argument could not be resolved into a guild object.
+    """
+    if arg.data.isdigit():
+        guild_id = int(arg.data)
+        guild = await arg.context.bot.rest.fetch_guild_preview(guild_id)
     else:
-        emoji = arg.context.bot.cache.get_emoji(emoji_id)
-        if emoji is None:
-            emoji = await arg.context.bot.rest.fetch_emoji(arg.context.guild_id, emoji_id)
-    return _raise_if_not_none(emoji)
+        guilds = arg.context.bot.cache.get_available_guilds_view()
+        guild = utils.get(guilds.values(), name=arg.data)
+
+        guild = await arg.context.bot.rest.fetch_guild_preview(guild.id)
+
+    return _raise_if_not_none(guild)
 
 
 async def message_converter(arg: WrappedArg) -> hikari.Message:
@@ -402,7 +423,8 @@ if typing.TYPE_CHECKING:
     voice_channel_converter = guild_voice_channel_converter
     category_converter = hikari.GuildCategory
     role_converter = hikari.Role
-    custom_emoji_converter = hikari.KnownCustomEmoji
+    emoji_converter = hikari.Emoji
+    guild_converter = hikari.GuildPreview
     message_converter = hikari.Message
     invite_converter = hikari.Invite
     colour_converter = hikari.Colour
