@@ -34,27 +34,32 @@ from lightbulb import utils
 
 if typing.TYPE_CHECKING:
     from lightbulb import command_handler
-    from lightbulb import context
+    from lightbulb import context as context_
 
 
-def get_help_text(object: typing.Union[commands.Command, plugins.Plugin]) -> str:
+def _format_help_text(help_text: str) -> str:
+    segments = help_text.split("\n\n")
+    return "\n".join(seg.replace("\n", " ").strip() for seg in segments)
+
+
+def get_help_text(obj: typing.Union[commands.Command, plugins.Plugin]) -> str:
     """
     Get the help text for a command, group or plugin, extracted from its docstring.
 
     Args:
-        object (Union[ :obj:`~.commands.Command`, :obj:`~.commands.Group`, :obj:`~.plugins.Plugin` ]): The
+        obj (Union[ :obj:`~.commands.Command`, :obj:`~.commands.Group`, :obj:`~.plugins.Plugin` ]): The
             object to get the help text for.
 
     Returns:
         :obj:`str`: The extracted help text, or an empty string if no help text has
         been provided for the object.
     """
-    if not isinstance(object, plugins.Plugin):
-        doc = inspect.getdoc(object._callback)
-        return doc if doc is not None else ""
+    if not isinstance(obj, plugins.Plugin):
+        doc = inspect.getdoc(obj._callback)
+        return _format_help_text(doc if doc is not None else "")
     else:
-        doc = inspect.getdoc(object)
-        return doc if doc != inspect.getdoc(plugins.Plugin) else ""
+        doc = inspect.getdoc(obj)
+        return _format_help_text(doc if doc != inspect.getdoc(plugins.Plugin) else "")
 
 
 def get_command_signature(command: commands.Command) -> str:
@@ -72,7 +77,7 @@ def get_command_signature(command: commands.Command) -> str:
     signature = inspect.signature(command._callback)
 
     items = [command.qualified_name]
-    num_args = len(signature.parameters) - command.arg_details.max_args
+    num_args = len(signature.parameters) - command.arg_details.maximum_arguments
     for name, param in list(signature.parameters.items())[num_args:]:
         if param.default is param.empty:
             items.append(f"<{name}>")
@@ -82,7 +87,7 @@ def get_command_signature(command: commands.Command) -> str:
 
 
 async def filter_commands(
-    context: context.Context,
+    context: context_.Context,
     command_list: typing.Iterable[commands.Command],
 ) -> typing.List[commands.Command]:
     """
@@ -109,14 +114,15 @@ async def filter_commands(
 
 
 @commands.command(name="help")
-async def _help_cmd(ctx):
+async def _help_cmd(ctx: context_.Context) -> None:
     """
     Displays help for the bot, a command, or a category.
+
     If no object is specified with the command then a help menu
     for the bot as a whole is displayed instead.
     """
     obj = ctx.message.content[len(f"{ctx.prefix}{ctx.invoked_with}") :].strip().split()
-    await ctx.bot._help_impl.resolve_help_obj(ctx, obj)
+    await ctx.bot.help_command.resolve_help_obj(ctx, obj)
 
 
 class HelpCommand:
@@ -134,7 +140,7 @@ class HelpCommand:
             self.bot.add_command(_help_cmd)
 
     @staticmethod
-    async def send_paginated_help(text: typing.Sequence[str], context: context.Context) -> None:
+    async def send_paginated_help(text: typing.Sequence[str], context: context_.Context) -> None:
         """
         Paginate the help text using :obj:`~.utils.pag.StringPaginator` and send each
         of the created pages to the context in order. Note that by default, only the
@@ -154,7 +160,7 @@ class HelpCommand:
         for page in pag.build_pages():
             await context.reply(page)
 
-    async def resolve_help_obj(self, context: context.Context, obj: typing.List[str]) -> None:
+    async def resolve_help_obj(self, context: context_.Context, obj: typing.List[str]) -> None:
         """
         Resolve the object to send help information for from the
         arguments passed to the help command.
@@ -202,7 +208,7 @@ class HelpCommand:
             else:
                 await self.object_not_found(context, " ".join(obj))
 
-    async def object_not_found(self, context: context.Context, name: str) -> None:
+    async def object_not_found(self, context: context_.Context, name: str) -> None:
         """
         Method called when help is requested for an object that does not exist.
 
@@ -215,7 +221,7 @@ class HelpCommand:
         """
         await context.reply(f"`{name}` is not a valid command, group or category.")
 
-    async def send_help_overview(self, context: context.Context) -> None:
+    async def send_help_overview(self, context: context_.Context) -> None:
         """
         Method called when the help command is run without any arguments.
 
@@ -246,7 +252,7 @@ class HelpCommand:
         help_text.append(f"> \n> Use `{context.clean_prefix}help [command]` for more information.")
         await self.send_paginated_help(help_text, context)
 
-    async def send_plugin_help(self, context: context.Context, plugin: plugins.Plugin) -> None:
+    async def send_plugin_help(self, context: context_.Context, plugin: plugins.Plugin) -> None:
         """
         Method called when the help command is run with an argument that
         resolves into the name of a plugin.
@@ -267,7 +273,7 @@ class HelpCommand:
         ]
         await context.reply("\n> ".join(help_text))
 
-    async def send_command_help(self, context: context.Context, command: commands.Command) -> None:
+    async def send_command_help(self, context: context_.Context, command: commands.Command) -> None:
         """
         Method called when the help command is run with an argument that
         resolves into the name of a registered command.
@@ -287,7 +293,7 @@ class HelpCommand:
         ]
         await context.reply("\n> ".join(help_text))
 
-    async def send_group_help(self, context: context.Context, group: commands.Group) -> None:
+    async def send_group_help(self, context: context_.Context, group: commands.Group) -> None:
         """
         Method called when the help command is run with an argument that
         resolves into the name of a registered command group.
